==> kubernetes-model-core-5.12.0-sources.jar: io/fabric8/kubernetes/api/model/EphemeralContainerBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class EphemeralContainerBuilder extends io.fabric8.kubernetes.api.model.EphemeralContainerFluentImpl<io.fabric8.kubernetes.api.model.EphemeralContainerBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.EphemeralContainer,io.fabric8.kubernetes.api.model.EphemeralContainerBuilder>{
  public EphemeralContainerBuilder() {
    this(false);
  }
  public EphemeralContainerBuilder(java.lang.Boolean validationEnabled) {
    this(new EphemeralContainer(), validationEnabled);
  }
  public EphemeralContainerBuilder(io.fabric8.kubernetes.api.model.EphemeralContainerFluent<?> fluent) {
    this(fluent, false);
  }
  public EphemeralContainerBuilder(io.fabric8.kubernetes.api.model.EphemeralContainerFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new EphemeralContainer(), validationEnabled);
  }
  public EphemeralContainerBuilder(io.fabric8.kubernetes.api.model.EphemeralContainerFluent<?> fluent,io.fabric8.kubernetes.api.model.EphemeralContainer instance) {
    this(fluent, instance, false);
  }
  public EphemeralContainerBuilder(io.fabric8.kubernetes.api.model.EphemeralContainerFluent<?> fluent,io.fabric8.kubernetes.api.model.EphemeralContainer instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withArgs(instance.getArgs()); 
    fluent.withCommand(instance.getCommand()); 
    fluent.withEnv(instance.getEnv()); 
    fluent.withEnvFrom(instance.getEnvFrom()); 
    fluent.withImage(instance.getImage()); 
    fluent.withImagePullPolicy(instance.getImagePullPolicy()); 
    fluent.withLifecycle(instance.getLifecycle()); 
    fluent.withLivenessProbe(instance.getLivenessProbe()); 
    fluent.withName(instance.getName()); 
    fluent.withPorts(instance.getPorts()); 
    fluent.withReadinessProbe(instance.getReadinessProbe()); 
    fluent.withResources(instance.getResources()); 
    fluent.withSecurityContext(instance.getSecurityContext()); 
    fluent.withStartupProbe(instance.getStartupProbe()); 
    fluent.withStdin(instance.getStdin()); 
    fluent.withStdinOnce(instance.getStdinOnce()); 
    fluent.withTargetContainerName(instance.getTargetContainerName()); 
    fluent.withTerminationMessagePath(instance.getTerminationMessagePath()); 
    fluent.withTerminationMessagePolicy(instance.getTerminationMessagePolicy()); 
    fluent.withTty(instance.getTty()); 
    fluent.withVolumeDevices(instance.getVolumeDevices()); 
    fluent.withVolumeMounts(instance.getVolumeMounts()); 
    fluent.withWorkingDir(instance.getWorkingDir()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public EphemeralContainerBuilder(io.fabric8.kubernetes.api.model.EphemeralContainer instance) {
    this(instance,false);
  }
  public EphemeralContainerBuilder(io.fabric8.kubernetes.api.model.EphemeralContainer instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withArgs(instance.getArgs()); 
    this.withCommand(instance.getCommand()); 
    this.withEnv(instance.getEnv()); 
    this.withEnvFrom(instance.getEnvFrom()); 
    this.withImage(instance.getImage()); 
    this.withImagePullPolicy(instance.getImagePullPolicy()); 
    this.withLifecycle(instance.getLifecycle()); 
    this.withLivenessProbe(instance.getLivenessProbe()); 
    this.withName(instance.getName()); 
    this.withPorts(instance.getPorts()); 
    this.withReadinessProbe(instance.getReadinessProbe()); 
    this.withResources(instance.getResources()); 
    this.withSecurityContext(instance.getSecurityContext()); 
    this.withStartupProbe(instance.getStartupProbe()); 
    this.withStdin(instance.getStdin()); 
    this.withStdinOnce(instance.getStdinOnce()); 
    this.withTargetContainerName(instance.getTargetContainerName()); 
    this.withTerminationMessagePath(instance.getTerminationMessagePath()); 
    this.withTerminationMessagePolicy(instance.getTerminationMessagePolicy()); 
    this.withTty(instance.getTty()); 
    this.withVolumeDevices(instance.getVolumeDevices()); 
    this.withVolumeMounts(instance.getVolumeMounts()); 
    this.withWorkingDir(instance.getWorkingDir()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.EphemeralContainerFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.EphemeralContainer build() {
    EphemeralContainer buildable = new EphemeralContainer(fluent.getArgs(),fluent.getCommand(),fluent.getEnv(),fluent.getEnvFrom(),fluent.getImage(),fluent.getImagePullPolicy(),fluent.getLifecycle(),fluent.getLivenessProbe(),fluent.getName(),fluent.getPorts(),fluent.getReadinessProbe(),fluent.getResources(),fluent.getSecurityContext(),fluent.getStartupProbe(),fluent.getStdin(),fluent.getStdinOnce(),fluent.getTargetContainerName(),fluent.getTerminationMessagePath(),fluent.getTerminationMessagePolicy(),fluent.getTty(),fluent.getVolumeDevices(),fluent.getVolumeMounts(),fluent.getWorkingDir());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EphemeralContainerBuilder that = (EphemeralContainerBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-6.4.1-sources.jar: io/fabric8/kubernetes/api/model/EphemeralContainerBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EphemeralContainerBuilder extends EphemeralContainerFluentImpl<EphemeralContainerBuilder> implements VisitableBuilder<EphemeralContainer,EphemeralContainerBuilder>{
  public EphemeralContainerBuilder() {
    this(false);
  }
  public EphemeralContainerBuilder(Boolean validationEnabled) {
    this(new EphemeralContainer(), validationEnabled);
  }
  public EphemeralContainerBuilder(EphemeralContainerFluent<?> fluent) {
    this(fluent, false);
  }
  public EphemeralContainerBuilder(EphemeralContainerFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EphemeralContainer(), validationEnabled);
  }
  public EphemeralContainerBuilder(EphemeralContainerFluent<?> fluent,EphemeralContainer instance) {
    this(fluent, instance, false);
  }
  public EphemeralContainerBuilder(EphemeralContainerFluent<?> fluent,EphemeralContainer instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withArgs(instance.getArgs()); 
    fluent.withCommand(instance.getCommand()); 
    fluent.withEnv(instance.getEnv()); 
    fluent.withEnvFrom(instance.getEnvFrom()); 
    fluent.withImage(instance.getImage()); 
    fluent.withImagePullPolicy(instance.getImagePullPolicy()); 
    fluent.withLifecycle(instance.getLifecycle()); 
    fluent.withLivenessProbe(instance.getLivenessProbe()); 
    fluent.withName(instance.getName()); 
    fluent.withPorts(instance.getPorts()); 
    fluent.withReadinessProbe(instance.getReadinessProbe()); 
    fluent.withResources(instance.getResources()); 
    fluent.withSecurityContext(instance.getSecurityContext()); 
    fluent.withStartupProbe(instance.getStartupProbe()); 
    fluent.withStdin(instance.getStdin()); 
    fluent.withStdinOnce(instance.getStdinOnce()); 
    fluent.withTargetContainerName(instance.getTargetContainerName()); 
    fluent.withTerminationMessagePath(instance.getTerminationMessagePath()); 
    fluent.withTerminationMessagePolicy(instance.getTerminationMessagePolicy()); 
    fluent.withTty(instance.getTty()); 
    fluent.withVolumeDevices(instance.getVolumeDevices()); 
    fluent.withVolumeMounts(instance.getVolumeMounts()); 
    fluent.withWorkingDir(instance.getWorkingDir()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public EphemeralContainerBuilder(EphemeralContainer instance) {
    this(instance,false);
  }
  public EphemeralContainerBuilder(EphemeralContainer instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withArgs(instance.getArgs()); 
    this.withCommand(instance.getCommand()); 
    this.withEnv(instance.getEnv()); 
    this.withEnvFrom(instance.getEnvFrom()); 
    this.withImage(instance.getImage()); 
    this.withImagePullPolicy(instance.getImagePullPolicy()); 
    this.withLifecycle(instance.getLifecycle()); 
    this.withLivenessProbe(instance.getLivenessProbe()); 
    this.withName(instance.getName()); 
    this.withPorts(instance.getPorts()); 
    this.withReadinessProbe(instance.getReadinessProbe()); 
    this.withResources(instance.getResources()); 
    this.withSecurityContext(instance.getSecurityContext()); 
    this.withStartupProbe(instance.getStartupProbe()); 
    this.withStdin(instance.getStdin()); 
    this.withStdinOnce(instance.getStdinOnce()); 
    this.withTargetContainerName(instance.getTargetContainerName()); 
    this.withTerminationMessagePath(instance.getTerminationMessagePath()); 
    this.withTerminationMessagePolicy(instance.getTerminationMessagePolicy()); 
    this.withTty(instance.getTty()); 
    this.withVolumeDevices(instance.getVolumeDevices()); 
    this.withVolumeMounts(instance.getVolumeMounts()); 
    this.withWorkingDir(instance.getWorkingDir()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  EphemeralContainerFluent<?> fluent;
  Boolean validationEnabled;
  public EphemeralContainer build() {
    EphemeralContainer buildable = new EphemeralContainer(fluent.getArgs(),fluent.getCommand(),fluent.getEnv(),fluent.getEnvFrom(),fluent.getImage(),fluent.getImagePullPolicy(),fluent.getLifecycle(),fluent.getLivenessProbe(),fluent.getName(),fluent.getPorts(),fluent.getReadinessProbe(),fluent.getResources(),fluent.getSecurityContext(),fluent.getStartupProbe(),fluent.getStdin(),fluent.getStdinOnce(),fluent.getTargetContainerName(),fluent.getTerminationMessagePath(),fluent.getTerminationMessagePolicy(),fluent.getTty(),fluent.getVolumeDevices(),fluent.getVolumeMounts(),fluent.getWorkingDir());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
